pub struct EbbinghausPolicy { /* private fields */ }Expand description
Ebbinghaus forgetting curve eviction policy.
Score formula:
score = exp(-t / (S * ln(1 + n)))
Where:
t= seconds sincelast_accessed(orcreated_atif never accessed)S=retention_strength(higher = slower decay)n=access_count
Entries with a high access count or recent access get higher scores and are less likely to be evicted.
Implementations