pub struct ActivatedFact {
pub edge: Edge,
pub activation_score: f32,
}Expand description
A graph edge traversed during spreading activation, with its activation score.
Fields
edge: EdgeThe traversed edge.
activation_score: f32Activation score of the source or target entity at time of traversal.