pub struct ExtractedEdge {
pub source: String,
pub target: String,
pub relation: String,
pub fact: String,
pub temporal_hint: Option<String>,
}Fields
source: Stringtarget: Stringrelation: Stringfact: Stringtemporal_hint: Option<String>Trait Implementations
Sourceimpl Clone for ExtractedEdge
impl Clone for ExtractedEdge
Sourcefn clone(&self) -> ExtractedEdge
fn clone(&self) -> ExtractedEdge
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractedEdge
impl Debug for ExtractedEdge
Sourceimpl<'de> Deserialize<'de> for ExtractedEdge
impl<'de> Deserialize<'de> for ExtractedEdge
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractedEdge
impl JsonSchema for ExtractedEdge
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractedEdge
impl PartialEq for ExtractedEdge
Sourceimpl Serialize for ExtractedEdge
impl Serialize for ExtractedEdge
impl StructuralPartialEq for ExtractedEdge