pub struct ExtractedEntity {
pub name: String,
pub entity_type: String,
pub summary: Option<String>,
}Fields
name: Stringentity_type: Stringsummary: Option<String>Trait Implementations
Sourceimpl Clone for ExtractedEntity
impl Clone for ExtractedEntity
Sourcefn clone(&self) -> ExtractedEntity
fn clone(&self) -> ExtractedEntity
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractedEntity
impl Debug for ExtractedEntity
Sourceimpl<'de> Deserialize<'de> for ExtractedEntity
impl<'de> Deserialize<'de> for ExtractedEntity
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractedEntity
impl JsonSchema for ExtractedEntity
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractedEntity
impl PartialEq for ExtractedEntity
Sourceimpl Serialize for ExtractedEntity
impl Serialize for ExtractedEntity
impl StructuralPartialEq for ExtractedEntity