pub struct ExtractionResult {
pub entities: Vec<ExtractedEntity>,
pub edges: Vec<ExtractedEdge>,
}Fields
entities: Vec<ExtractedEntity>edges: Vec<ExtractedEdge>Trait Implementations
Sourceimpl Clone for ExtractionResult
impl Clone for ExtractionResult
Sourcefn clone(&self) -> ExtractionResult
fn clone(&self) -> ExtractionResult
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for ExtractionResult
impl Debug for ExtractionResult
Sourceimpl<'de> Deserialize<'de> for ExtractionResult
impl<'de> Deserialize<'de> for ExtractionResult
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ExtractionResult
impl JsonSchema for ExtractionResult
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for ExtractionResult
impl PartialEq for ExtractionResult
Sourceimpl Serialize for ExtractionResult
impl Serialize for ExtractionResult
impl StructuralPartialEq for ExtractionResult