pub struct StructuredSummary {
pub summary: String,
pub key_facts: Vec<String>,
pub entities: Vec<String>,
}Fields
summary: Stringkey_facts: Vec<String>entities: Vec<String>Trait Implementations
Sourceimpl Clone for StructuredSummary
impl Clone for StructuredSummary
Sourcefn clone(&self) -> StructuredSummary
fn clone(&self) -> StructuredSummary
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for StructuredSummary
impl Debug for StructuredSummary
Sourceimpl<'de> Deserialize<'de> for StructuredSummary
impl<'de> Deserialize<'de> for StructuredSummary
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for StructuredSummary
impl JsonSchema for StructuredSummary
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for StructuredSummary
impl RefUnwindSafe for StructuredSummary
impl Send for StructuredSummary
impl Sync for StructuredSummary
impl Unpin for StructuredSummary
impl UnsafeUnpin for StructuredSummary
impl UnwindSafe for StructuredSummary